# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OsnArgs', 'Osn']

@pulumi.input_type
class OsnArgs:
    def __init__(__self__, *,
                 ad: pulumi.Input[str],
                 blockchain_platform_id: pulumi.Input[str],
                 ocpu_allocation_param: Optional[pulumi.Input['OsnOcpuAllocationParamArgs']] = None):
        """
        The set of arguments for constructing a Osn resource.
        :param pulumi.Input[str] ad: Availability Domain to place new OSN
        :param pulumi.Input[str] blockchain_platform_id: Unique service identifier.
        :param pulumi.Input['OsnOcpuAllocationParamArgs'] ocpu_allocation_param: (Updatable) OCPU allocation parameter
        """
        pulumi.set(__self__, "ad", ad)
        pulumi.set(__self__, "blockchain_platform_id", blockchain_platform_id)
        if ocpu_allocation_param is not None:
            pulumi.set(__self__, "ocpu_allocation_param", ocpu_allocation_param)

    @property
    @pulumi.getter
    def ad(self) -> pulumi.Input[str]:
        """
        Availability Domain to place new OSN
        """
        return pulumi.get(self, "ad")

    @ad.setter
    def ad(self, value: pulumi.Input[str]):
        pulumi.set(self, "ad", value)

    @property
    @pulumi.getter(name="blockchainPlatformId")
    def blockchain_platform_id(self) -> pulumi.Input[str]:
        """
        Unique service identifier.
        """
        return pulumi.get(self, "blockchain_platform_id")

    @blockchain_platform_id.setter
    def blockchain_platform_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "blockchain_platform_id", value)

    @property
    @pulumi.getter(name="ocpuAllocationParam")
    def ocpu_allocation_param(self) -> Optional[pulumi.Input['OsnOcpuAllocationParamArgs']]:
        """
        (Updatable) OCPU allocation parameter
        """
        return pulumi.get(self, "ocpu_allocation_param")

    @ocpu_allocation_param.setter
    def ocpu_allocation_param(self, value: Optional[pulumi.Input['OsnOcpuAllocationParamArgs']]):
        pulumi.set(self, "ocpu_allocation_param", value)


@pulumi.input_type
class _OsnState:
    def __init__(__self__, *,
                 ad: Optional[pulumi.Input[str]] = None,
                 blockchain_platform_id: Optional[pulumi.Input[str]] = None,
                 ocpu_allocation_param: Optional[pulumi.Input['OsnOcpuAllocationParamArgs']] = None,
                 osn_key: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Osn resources.
        :param pulumi.Input[str] ad: Availability Domain to place new OSN
        :param pulumi.Input[str] blockchain_platform_id: Unique service identifier.
        :param pulumi.Input['OsnOcpuAllocationParamArgs'] ocpu_allocation_param: (Updatable) OCPU allocation parameter
        :param pulumi.Input[str] osn_key: OSN identifier
        :param pulumi.Input[str] state: The current state of the OSN.
        """
        if ad is not None:
            pulumi.set(__self__, "ad", ad)
        if blockchain_platform_id is not None:
            pulumi.set(__self__, "blockchain_platform_id", blockchain_platform_id)
        if ocpu_allocation_param is not None:
            pulumi.set(__self__, "ocpu_allocation_param", ocpu_allocation_param)
        if osn_key is not None:
            pulumi.set(__self__, "osn_key", osn_key)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter
    def ad(self) -> Optional[pulumi.Input[str]]:
        """
        Availability Domain to place new OSN
        """
        return pulumi.get(self, "ad")

    @ad.setter
    def ad(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ad", value)

    @property
    @pulumi.getter(name="blockchainPlatformId")
    def blockchain_platform_id(self) -> Optional[pulumi.Input[str]]:
        """
        Unique service identifier.
        """
        return pulumi.get(self, "blockchain_platform_id")

    @blockchain_platform_id.setter
    def blockchain_platform_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blockchain_platform_id", value)

    @property
    @pulumi.getter(name="ocpuAllocationParam")
    def ocpu_allocation_param(self) -> Optional[pulumi.Input['OsnOcpuAllocationParamArgs']]:
        """
        (Updatable) OCPU allocation parameter
        """
        return pulumi.get(self, "ocpu_allocation_param")

    @ocpu_allocation_param.setter
    def ocpu_allocation_param(self, value: Optional[pulumi.Input['OsnOcpuAllocationParamArgs']]):
        pulumi.set(self, "ocpu_allocation_param", value)

    @property
    @pulumi.getter(name="osnKey")
    def osn_key(self) -> Optional[pulumi.Input[str]]:
        """
        OSN identifier
        """
        return pulumi.get(self, "osn_key")

    @osn_key.setter
    def osn_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "osn_key", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the OSN.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


class Osn(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ad: Optional[pulumi.Input[str]] = None,
                 blockchain_platform_id: Optional[pulumi.Input[str]] = None,
                 ocpu_allocation_param: Optional[pulumi.Input[pulumi.InputType['OsnOcpuAllocationParamArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Osn resource in Oracle Cloud Infrastructure Blockchain service.

        Create Blockchain Platform Osn

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_osn = oci.blockchain.Osn("testOsn",
            ad=var["osn_ad"],
            blockchain_platform_id=oci_blockchain_blockchain_platform["test_blockchain_platform"]["id"],
            ocpu_allocation_param=oci.blockchain.OsnOcpuAllocationParamArgs(
                ocpu_allocation_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        Osns can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Blockchain/osn:Osn test_osn "blockchainPlatforms/{blockchainPlatformId}/osns/{osnId}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ad: Availability Domain to place new OSN
        :param pulumi.Input[str] blockchain_platform_id: Unique service identifier.
        :param pulumi.Input[pulumi.InputType['OsnOcpuAllocationParamArgs']] ocpu_allocation_param: (Updatable) OCPU allocation parameter
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OsnArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Osn resource in Oracle Cloud Infrastructure Blockchain service.

        Create Blockchain Platform Osn

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_osn = oci.blockchain.Osn("testOsn",
            ad=var["osn_ad"],
            blockchain_platform_id=oci_blockchain_blockchain_platform["test_blockchain_platform"]["id"],
            ocpu_allocation_param=oci.blockchain.OsnOcpuAllocationParamArgs(
                ocpu_allocation_number=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ))
        ```

        ## Import

        Osns can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Blockchain/osn:Osn test_osn "blockchainPlatforms/{blockchainPlatformId}/osns/{osnId}"
        ```

        :param str resource_name: The name of the resource.
        :param OsnArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OsnArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ad: Optional[pulumi.Input[str]] = None,
                 blockchain_platform_id: Optional[pulumi.Input[str]] = None,
                 ocpu_allocation_param: Optional[pulumi.Input[pulumi.InputType['OsnOcpuAllocationParamArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OsnArgs.__new__(OsnArgs)

            if ad is None and not opts.urn:
                raise TypeError("Missing required property 'ad'")
            __props__.__dict__["ad"] = ad
            if blockchain_platform_id is None and not opts.urn:
                raise TypeError("Missing required property 'blockchain_platform_id'")
            __props__.__dict__["blockchain_platform_id"] = blockchain_platform_id
            __props__.__dict__["ocpu_allocation_param"] = ocpu_allocation_param
            __props__.__dict__["osn_key"] = None
            __props__.__dict__["state"] = None
        super(Osn, __self__).__init__(
            'oci:Blockchain/osn:Osn',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ad: Optional[pulumi.Input[str]] = None,
            blockchain_platform_id: Optional[pulumi.Input[str]] = None,
            ocpu_allocation_param: Optional[pulumi.Input[pulumi.InputType['OsnOcpuAllocationParamArgs']]] = None,
            osn_key: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None) -> 'Osn':
        """
        Get an existing Osn resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] ad: Availability Domain to place new OSN
        :param pulumi.Input[str] blockchain_platform_id: Unique service identifier.
        :param pulumi.Input[pulumi.InputType['OsnOcpuAllocationParamArgs']] ocpu_allocation_param: (Updatable) OCPU allocation parameter
        :param pulumi.Input[str] osn_key: OSN identifier
        :param pulumi.Input[str] state: The current state of the OSN.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OsnState.__new__(_OsnState)

        __props__.__dict__["ad"] = ad
        __props__.__dict__["blockchain_platform_id"] = blockchain_platform_id
        __props__.__dict__["ocpu_allocation_param"] = ocpu_allocation_param
        __props__.__dict__["osn_key"] = osn_key
        __props__.__dict__["state"] = state
        return Osn(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def ad(self) -> pulumi.Output[str]:
        """
        Availability Domain to place new OSN
        """
        return pulumi.get(self, "ad")

    @property
    @pulumi.getter(name="blockchainPlatformId")
    def blockchain_platform_id(self) -> pulumi.Output[str]:
        """
        Unique service identifier.
        """
        return pulumi.get(self, "blockchain_platform_id")

    @property
    @pulumi.getter(name="ocpuAllocationParam")
    def ocpu_allocation_param(self) -> pulumi.Output['outputs.OsnOcpuAllocationParam']:
        """
        (Updatable) OCPU allocation parameter
        """
        return pulumi.get(self, "ocpu_allocation_param")

    @property
    @pulumi.getter(name="osnKey")
    def osn_key(self) -> pulumi.Output[str]:
        """
        OSN identifier
        """
        return pulumi.get(self, "osn_key")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the OSN.
        """
        return pulumi.get(self, "state")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetSubscriptionResult',
    'AwaitableGetSubscriptionResult',
    'get_subscription',
    'get_subscription_output',
]

@pulumi.output_type
class GetSubscriptionResult:
    """
    A collection of values returned by getSubscription.
    """
    def __init__(__self__, bill_to_cust_account_id=None, billing_addresses=None, compartment_id=None, currency_code=None, email=None, gsi_org_code=None, id=None, is_intent_to_pay=None, language_code=None, organization_id=None, osp_home_region=None, payment_gateways=None, payment_options=None, plan_type=None, ship_to_cust_acct_role_id=None, ship_to_cust_acct_site_id=None, subscription_id=None, subscription_plan_number=None, subscriptions=None, tax_infos=None, time_plan_upgrade=None, time_start=None, upgrade_state=None, upgrade_state_details=None):
        if bill_to_cust_account_id and not isinstance(bill_to_cust_account_id, str):
            raise TypeError("Expected argument 'bill_to_cust_account_id' to be a str")
        pulumi.set(__self__, "bill_to_cust_account_id", bill_to_cust_account_id)
        if billing_addresses and not isinstance(billing_addresses, list):
            raise TypeError("Expected argument 'billing_addresses' to be a list")
        pulumi.set(__self__, "billing_addresses", billing_addresses)
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if currency_code and not isinstance(currency_code, str):
            raise TypeError("Expected argument 'currency_code' to be a str")
        pulumi.set(__self__, "currency_code", currency_code)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if gsi_org_code and not isinstance(gsi_org_code, str):
            raise TypeError("Expected argument 'gsi_org_code' to be a str")
        pulumi.set(__self__, "gsi_org_code", gsi_org_code)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if is_intent_to_pay and not isinstance(is_intent_to_pay, bool):
            raise TypeError("Expected argument 'is_intent_to_pay' to be a bool")
        pulumi.set(__self__, "is_intent_to_pay", is_intent_to_pay)
        if language_code and not isinstance(language_code, str):
            raise TypeError("Expected argument 'language_code' to be a str")
        pulumi.set(__self__, "language_code", language_code)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if osp_home_region and not isinstance(osp_home_region, str):
            raise TypeError("Expected argument 'osp_home_region' to be a str")
        pulumi.set(__self__, "osp_home_region", osp_home_region)
        if payment_gateways and not isinstance(payment_gateways, list):
            raise TypeError("Expected argument 'payment_gateways' to be a list")
        pulumi.set(__self__, "payment_gateways", payment_gateways)
        if payment_options and not isinstance(payment_options, list):
            raise TypeError("Expected argument 'payment_options' to be a list")
        pulumi.set(__self__, "payment_options", payment_options)
        if plan_type and not isinstance(plan_type, str):
            raise TypeError("Expected argument 'plan_type' to be a str")
        pulumi.set(__self__, "plan_type", plan_type)
        if ship_to_cust_acct_role_id and not isinstance(ship_to_cust_acct_role_id, str):
            raise TypeError("Expected argument 'ship_to_cust_acct_role_id' to be a str")
        pulumi.set(__self__, "ship_to_cust_acct_role_id", ship_to_cust_acct_role_id)
        if ship_to_cust_acct_site_id and not isinstance(ship_to_cust_acct_site_id, str):
            raise TypeError("Expected argument 'ship_to_cust_acct_site_id' to be a str")
        pulumi.set(__self__, "ship_to_cust_acct_site_id", ship_to_cust_acct_site_id)
        if subscription_id and not isinstance(subscription_id, str):
            raise TypeError("Expected argument 'subscription_id' to be a str")
        pulumi.set(__self__, "subscription_id", subscription_id)
        if subscription_plan_number and not isinstance(subscription_plan_number, str):
            raise TypeError("Expected argument 'subscription_plan_number' to be a str")
        pulumi.set(__self__, "subscription_plan_number", subscription_plan_number)
        if subscriptions and not isinstance(subscriptions, list):
            raise TypeError("Expected argument 'subscriptions' to be a list")
        pulumi.set(__self__, "subscriptions", subscriptions)
        if tax_infos and not isinstance(tax_infos, list):
            raise TypeError("Expected argument 'tax_infos' to be a list")
        pulumi.set(__self__, "tax_infos", tax_infos)
        if time_plan_upgrade and not isinstance(time_plan_upgrade, str):
            raise TypeError("Expected argument 'time_plan_upgrade' to be a str")
        pulumi.set(__self__, "time_plan_upgrade", time_plan_upgrade)
        if time_start and not isinstance(time_start, str):
            raise TypeError("Expected argument 'time_start' to be a str")
        pulumi.set(__self__, "time_start", time_start)
        if upgrade_state and not isinstance(upgrade_state, str):
            raise TypeError("Expected argument 'upgrade_state' to be a str")
        pulumi.set(__self__, "upgrade_state", upgrade_state)
        if upgrade_state_details and not isinstance(upgrade_state_details, str):
            raise TypeError("Expected argument 'upgrade_state_details' to be a str")
        pulumi.set(__self__, "upgrade_state_details", upgrade_state_details)

    @property
    @pulumi.getter(name="billToCustAccountId")
    def bill_to_cust_account_id(self) -> str:
        """
        Bill to customer Account id.
        """
        return pulumi.get(self, "bill_to_cust_account_id")

    @property
    @pulumi.getter(name="billingAddresses")
    def billing_addresses(self) -> Sequence['outputs.GetSubscriptionBillingAddressResult']:
        """
        Billing address details model.
        """
        return pulumi.get(self, "billing_addresses")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> str:
        """
        Currency code
        """
        return pulumi.get(self, "currency_code")

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="gsiOrgCode")
    def gsi_org_code(self) -> str:
        """
        GSI Subscription external code.
        """
        return pulumi.get(self, "gsi_org_code")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Subscription id identifier (OCID).
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="isIntentToPay")
    def is_intent_to_pay(self) -> bool:
        """
        Payment intension.
        """
        return pulumi.get(self, "is_intent_to_pay")

    @property
    @pulumi.getter(name="languageCode")
    def language_code(self) -> str:
        """
        Language short code (en, de, hu, etc)
        """
        return pulumi.get(self, "language_code")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        """
        GSI organization external identifier.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="ospHomeRegion")
    def osp_home_region(self) -> str:
        return pulumi.get(self, "osp_home_region")

    @property
    @pulumi.getter(name="paymentGateways")
    def payment_gateways(self) -> Sequence['outputs.GetSubscriptionPaymentGatewayResult']:
        """
        Payment gateway details.
        """
        return pulumi.get(self, "payment_gateways")

    @property
    @pulumi.getter(name="paymentOptions")
    def payment_options(self) -> Sequence['outputs.GetSubscriptionPaymentOptionResult']:
        """
        Payment option list of a subscription.
        """
        return pulumi.get(self, "payment_options")

    @property
    @pulumi.getter(name="planType")
    def plan_type(self) -> str:
        """
        Subscription plan type.
        """
        return pulumi.get(self, "plan_type")

    @property
    @pulumi.getter(name="shipToCustAcctRoleId")
    def ship_to_cust_acct_role_id(self) -> str:
        """
        Ship to customer account role.
        """
        return pulumi.get(self, "ship_to_cust_acct_role_id")

    @property
    @pulumi.getter(name="shipToCustAcctSiteId")
    def ship_to_cust_acct_site_id(self) -> str:
        """
        Ship to customer account site address id.
        """
        return pulumi.get(self, "ship_to_cust_acct_site_id")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> str:
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter(name="subscriptionPlanNumber")
    def subscription_plan_number(self) -> str:
        """
        Subscription plan number.
        """
        return pulumi.get(self, "subscription_plan_number")

    @property
    @pulumi.getter
    def subscriptions(self) -> Sequence['outputs.GetSubscriptionSubscriptionResult']:
        return pulumi.get(self, "subscriptions")

    @property
    @pulumi.getter(name="taxInfos")
    def tax_infos(self) -> Sequence['outputs.GetSubscriptionTaxInfoResult']:
        """
        Tax details.
        """
        return pulumi.get(self, "tax_infos")

    @property
    @pulumi.getter(name="timePlanUpgrade")
    def time_plan_upgrade(self) -> str:
        """
        Date of upgrade/conversion when planType changed from FREE_TIER to PAYG
        """
        return pulumi.get(self, "time_plan_upgrade")

    @property
    @pulumi.getter(name="timeStart")
    def time_start(self) -> str:
        """
        Start date of the subscription.
        """
        return pulumi.get(self, "time_start")

    @property
    @pulumi.getter(name="upgradeState")
    def upgrade_state(self) -> str:
        """
        Status of the upgrade.
        """
        return pulumi.get(self, "upgrade_state")

    @property
    @pulumi.getter(name="upgradeStateDetails")
    def upgrade_state_details(self) -> str:
        """
        This field is used to describe the Upgrade State in case of error (E.g. Upgrade failure caused by interfacing Tax details- TaxError)
        """
        return pulumi.get(self, "upgrade_state_details")


class AwaitableGetSubscriptionResult(GetSubscriptionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSubscriptionResult(
            bill_to_cust_account_id=self.bill_to_cust_account_id,
            billing_addresses=self.billing_addresses,
            compartment_id=self.compartment_id,
            currency_code=self.currency_code,
            email=self.email,
            gsi_org_code=self.gsi_org_code,
            id=self.id,
            is_intent_to_pay=self.is_intent_to_pay,
            language_code=self.language_code,
            organization_id=self.organization_id,
            osp_home_region=self.osp_home_region,
            payment_gateways=self.payment_gateways,
            payment_options=self.payment_options,
            plan_type=self.plan_type,
            ship_to_cust_acct_role_id=self.ship_to_cust_acct_role_id,
            ship_to_cust_acct_site_id=self.ship_to_cust_acct_site_id,
            subscription_id=self.subscription_id,
            subscription_plan_number=self.subscription_plan_number,
            subscriptions=self.subscriptions,
            tax_infos=self.tax_infos,
            time_plan_upgrade=self.time_plan_upgrade,
            time_start=self.time_start,
            upgrade_state=self.upgrade_state,
            upgrade_state_details=self.upgrade_state_details)


def get_subscription(compartment_id: Optional[str] = None,
                     osp_home_region: Optional[str] = None,
                     subscription_id: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSubscriptionResult:
    """
    This data source provides details about a specific Subscription resource in Oracle Cloud Infrastructure Osp Gateway service.

    Get the subscription plan.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_subscription = oci.OspGateway.get_subscription(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        osp_home_region=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        subscription_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str osp_home_region: The home region's public name of the logged in user.
    :param str subscription_id: Subscription id(OCID).
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['ospHomeRegion'] = osp_home_region
    __args__['subscriptionId'] = subscription_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:OspGateway/getSubscription:getSubscription', __args__, opts=opts, typ=GetSubscriptionResult).value

    return AwaitableGetSubscriptionResult(
        bill_to_cust_account_id=__ret__.bill_to_cust_account_id,
        billing_addresses=__ret__.billing_addresses,
        compartment_id=__ret__.compartment_id,
        currency_code=__ret__.currency_code,
        email=__ret__.email,
        gsi_org_code=__ret__.gsi_org_code,
        id=__ret__.id,
        is_intent_to_pay=__ret__.is_intent_to_pay,
        language_code=__ret__.language_code,
        organization_id=__ret__.organization_id,
        osp_home_region=__ret__.osp_home_region,
        payment_gateways=__ret__.payment_gateways,
        payment_options=__ret__.payment_options,
        plan_type=__ret__.plan_type,
        ship_to_cust_acct_role_id=__ret__.ship_to_cust_acct_role_id,
        ship_to_cust_acct_site_id=__ret__.ship_to_cust_acct_site_id,
        subscription_id=__ret__.subscription_id,
        subscription_plan_number=__ret__.subscription_plan_number,
        subscriptions=__ret__.subscriptions,
        tax_infos=__ret__.tax_infos,
        time_plan_upgrade=__ret__.time_plan_upgrade,
        time_start=__ret__.time_start,
        upgrade_state=__ret__.upgrade_state,
        upgrade_state_details=__ret__.upgrade_state_details)


@_utilities.lift_output_func(get_subscription)
def get_subscription_output(compartment_id: Optional[pulumi.Input[str]] = None,
                            osp_home_region: Optional[pulumi.Input[str]] = None,
                            subscription_id: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSubscriptionResult]:
    """
    This data source provides details about a specific Subscription resource in Oracle Cloud Infrastructure Osp Gateway service.

    Get the subscription plan.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_subscription = oci.OspGateway.get_subscription(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        osp_home_region=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        subscription_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
    :param str osp_home_region: The home region's public name of the logged in user.
    :param str subscription_id: Subscription id(OCID).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult',
    'AwaitableGetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult',
    'get_managed_database_optimizer_statistics_advisor_execution_script',
    'get_managed_database_optimizer_statistics_advisor_execution_script_output',
]

@pulumi.output_type
class GetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult:
    """
    A collection of values returned by getManagedDatabaseOptimizerStatisticsAdvisorExecutionScript.
    """
    def __init__(__self__, execution_name=None, id=None, managed_database_id=None, script=None, task_name=None):
        if execution_name and not isinstance(execution_name, str):
            raise TypeError("Expected argument 'execution_name' to be a str")
        pulumi.set(__self__, "execution_name", execution_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if managed_database_id and not isinstance(managed_database_id, str):
            raise TypeError("Expected argument 'managed_database_id' to be a str")
        pulumi.set(__self__, "managed_database_id", managed_database_id)
        if script and not isinstance(script, str):
            raise TypeError("Expected argument 'script' to be a str")
        pulumi.set(__self__, "script", script)
        if task_name and not isinstance(task_name, str):
            raise TypeError("Expected argument 'task_name' to be a str")
        pulumi.set(__self__, "task_name", task_name)

    @property
    @pulumi.getter(name="executionName")
    def execution_name(self) -> str:
        return pulumi.get(self, "execution_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="managedDatabaseId")
    def managed_database_id(self) -> str:
        return pulumi.get(self, "managed_database_id")

    @property
    @pulumi.getter
    def script(self) -> str:
        """
        The Optimizer Statistics Advisor execution script.
        """
        return pulumi.get(self, "script")

    @property
    @pulumi.getter(name="taskName")
    def task_name(self) -> str:
        return pulumi.get(self, "task_name")


class AwaitableGetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult(GetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult(
            execution_name=self.execution_name,
            id=self.id,
            managed_database_id=self.managed_database_id,
            script=self.script,
            task_name=self.task_name)


def get_managed_database_optimizer_statistics_advisor_execution_script(execution_name: Optional[str] = None,
                                                                       managed_database_id: Optional[str] = None,
                                                                       task_name: Optional[str] = None,
                                                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult:
    """
    This data source provides details about a specific Managed Database Optimizer Statistics Advisor Execution Script resource in Oracle Cloud Infrastructure Database Management service.

    Gets the Oracle system-generated script for the specified Optimizer Statistics Advisor execution.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_optimizer_statistics_advisor_execution_script = oci.DatabaseManagement.get_managed_database_optimizer_statistics_advisor_execution_script(execution_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        task_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str execution_name: The name of the Optimizer Statistics Advisor execution.
    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str task_name: The name of the optimizer statistics collection execution task.
    """
    __args__ = dict()
    __args__['executionName'] = execution_name
    __args__['managedDatabaseId'] = managed_database_id
    __args__['taskName'] = task_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DatabaseManagement/getManagedDatabaseOptimizerStatisticsAdvisorExecutionScript:getManagedDatabaseOptimizerStatisticsAdvisorExecutionScript', __args__, opts=opts, typ=GetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult).value

    return AwaitableGetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult(
        execution_name=__ret__.execution_name,
        id=__ret__.id,
        managed_database_id=__ret__.managed_database_id,
        script=__ret__.script,
        task_name=__ret__.task_name)


@_utilities.lift_output_func(get_managed_database_optimizer_statistics_advisor_execution_script)
def get_managed_database_optimizer_statistics_advisor_execution_script_output(execution_name: Optional[pulumi.Input[str]] = None,
                                                                              managed_database_id: Optional[pulumi.Input[str]] = None,
                                                                              task_name: Optional[pulumi.Input[str]] = None,
                                                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetManagedDatabaseOptimizerStatisticsAdvisorExecutionScriptResult]:
    """
    This data source provides details about a specific Managed Database Optimizer Statistics Advisor Execution Script resource in Oracle Cloud Infrastructure Database Management service.

    Gets the Oracle system-generated script for the specified Optimizer Statistics Advisor execution.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_optimizer_statistics_advisor_execution_script = oci.DatabaseManagement.get_managed_database_optimizer_statistics_advisor_execution_script(execution_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        task_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str execution_name: The name of the Optimizer Statistics Advisor execution.
    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str task_name: The name of the optimizer statistics collection execution task.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetExternalDatabaseConnectorResult',
    'AwaitableGetExternalDatabaseConnectorResult',
    'get_external_database_connector',
    'get_external_database_connector_output',
]

@pulumi.output_type
class GetExternalDatabaseConnectorResult:
    """
    A collection of values returned by getExternalDatabaseConnector.
    """
    def __init__(__self__, compartment_id=None, connection_credentials=None, connection_status=None, connection_strings=None, connector_agent_id=None, connector_type=None, defined_tags=None, display_name=None, external_database_connector_id=None, external_database_id=None, freeform_tags=None, id=None, lifecycle_details=None, state=None, time_connection_status_last_updated=None, time_created=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if connection_credentials and not isinstance(connection_credentials, list):
            raise TypeError("Expected argument 'connection_credentials' to be a list")
        pulumi.set(__self__, "connection_credentials", connection_credentials)
        if connection_status and not isinstance(connection_status, str):
            raise TypeError("Expected argument 'connection_status' to be a str")
        pulumi.set(__self__, "connection_status", connection_status)
        if connection_strings and not isinstance(connection_strings, list):
            raise TypeError("Expected argument 'connection_strings' to be a list")
        pulumi.set(__self__, "connection_strings", connection_strings)
        if connector_agent_id and not isinstance(connector_agent_id, str):
            raise TypeError("Expected argument 'connector_agent_id' to be a str")
        pulumi.set(__self__, "connector_agent_id", connector_agent_id)
        if connector_type and not isinstance(connector_type, str):
            raise TypeError("Expected argument 'connector_type' to be a str")
        pulumi.set(__self__, "connector_type", connector_type)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if external_database_connector_id and not isinstance(external_database_connector_id, str):
            raise TypeError("Expected argument 'external_database_connector_id' to be a str")
        pulumi.set(__self__, "external_database_connector_id", external_database_connector_id)
        if external_database_id and not isinstance(external_database_id, str):
            raise TypeError("Expected argument 'external_database_id' to be a str")
        pulumi.set(__self__, "external_database_id", external_database_id)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_connection_status_last_updated and not isinstance(time_connection_status_last_updated, str):
            raise TypeError("Expected argument 'time_connection_status_last_updated' to be a str")
        pulumi.set(__self__, "time_connection_status_last_updated", time_connection_status_last_updated)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="connectionCredentials")
    def connection_credentials(self) -> Sequence['outputs.GetExternalDatabaseConnectorConnectionCredentialResult']:
        """
        Credentials used to connect to the database. Currently only the `DETAILS` type is supported for creating MACS connector crendentials.
        """
        return pulumi.get(self, "connection_credentials")

    @property
    @pulumi.getter(name="connectionStatus")
    def connection_status(self) -> str:
        """
        The status of connectivity to the external database.
        """
        return pulumi.get(self, "connection_status")

    @property
    @pulumi.getter(name="connectionStrings")
    def connection_strings(self) -> Sequence['outputs.GetExternalDatabaseConnectorConnectionStringResult']:
        """
        The Oracle Database connection string.
        """
        return pulumi.get(self, "connection_strings")

    @property
    @pulumi.getter(name="connectorAgentId")
    def connector_agent_id(self) -> str:
        """
        The ID of the agent used for the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        """
        return pulumi.get(self, "connector_agent_id")

    @property
    @pulumi.getter(name="connectorType")
    def connector_type(self) -> str:
        """
        The type of connector used by the external database resource.
        """
        return pulumi.get(self, "connector_type")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The user-friendly name for the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails). The name does not have to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="externalDatabaseConnectorId")
    def external_database_connector_id(self) -> str:
        return pulumi.get(self, "external_database_connector_id")

    @property
    @pulumi.getter(name="externalDatabaseId")
    def external_database_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external database resource.
        """
        return pulumi.get(self, "external_database_id")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the [external database connector](https://docs.cloud.oracle.com/iaas/api/#/en/database/latest/datatypes/CreateExternalDatabaseConnectorDetails).
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> str:
        """
        Additional information about the current lifecycle state.
        """
        return pulumi.get(self, "lifecycle_details")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current lifecycle state of the external database connector resource.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeConnectionStatusLastUpdated")
    def time_connection_status_last_updated(self) -> str:
        """
        The date and time the `connectionStatus` of this external connector was last updated.
        """
        return pulumi.get(self, "time_connection_status_last_updated")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the external connector was created.
        """
        return pulumi.get(self, "time_created")


class AwaitableGetExternalDatabaseConnectorResult(GetExternalDatabaseConnectorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetExternalDatabaseConnectorResult(
            compartment_id=self.compartment_id,
            connection_credentials=self.connection_credentials,
            connection_status=self.connection_status,
            connection_strings=self.connection_strings,
            connector_agent_id=self.connector_agent_id,
            connector_type=self.connector_type,
            defined_tags=self.defined_tags,
            display_name=self.display_name,
            external_database_connector_id=self.external_database_connector_id,
            external_database_id=self.external_database_id,
            freeform_tags=self.freeform_tags,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            state=self.state,
            time_connection_status_last_updated=self.time_connection_status_last_updated,
            time_created=self.time_created)


def get_external_database_connector(external_database_connector_id: Optional[str] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetExternalDatabaseConnectorResult:
    """
    This data source provides details about a specific External Database Connector resource in Oracle Cloud Infrastructure Database service.

    Gets information about the specified external database connector.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_external_database_connector = oci.Database.get_external_database_connector(external_database_connector_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str external_database_connector_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external database connector resource (`ExternalDatabaseConnectorId`).
    """
    __args__ = dict()
    __args__['externalDatabaseConnectorId'] = external_database_connector_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Database/getExternalDatabaseConnector:getExternalDatabaseConnector', __args__, opts=opts, typ=GetExternalDatabaseConnectorResult).value

    return AwaitableGetExternalDatabaseConnectorResult(
        compartment_id=__ret__.compartment_id,
        connection_credentials=__ret__.connection_credentials,
        connection_status=__ret__.connection_status,
        connection_strings=__ret__.connection_strings,
        connector_agent_id=__ret__.connector_agent_id,
        connector_type=__ret__.connector_type,
        defined_tags=__ret__.defined_tags,
        display_name=__ret__.display_name,
        external_database_connector_id=__ret__.external_database_connector_id,
        external_database_id=__ret__.external_database_id,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        lifecycle_details=__ret__.lifecycle_details,
        state=__ret__.state,
        time_connection_status_last_updated=__ret__.time_connection_status_last_updated,
        time_created=__ret__.time_created)


@_utilities.lift_output_func(get_external_database_connector)
def get_external_database_connector_output(external_database_connector_id: Optional[pulumi.Input[str]] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetExternalDatabaseConnectorResult]:
    """
    This data source provides details about a specific External Database Connector resource in Oracle Cloud Infrastructure Database service.

    Gets information about the specified external database connector.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_external_database_connector = oci.Database.get_external_database_connector(external_database_connector_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str external_database_connector_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the external database connector resource (`ExternalDatabaseConnectorId`).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult',
    'AwaitableGetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult',
    'get_managed_database_sql_tuning_advisor_tasks_summary_report',
    'get_managed_database_sql_tuning_advisor_tasks_summary_report_output',
]

@pulumi.output_type
class GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult:
    """
    A collection of values returned by getManagedDatabaseSqlTuningAdvisorTasksSummaryReport.
    """
    def __init__(__self__, begin_exec_id_greater_than_or_equal_to=None, end_exec_id_less_than_or_equal_to=None, id=None, index_findings=None, managed_database_id=None, object_stat_findings=None, search_period=None, sql_tuning_advisor_task_id=None, statistics=None, task_infos=None, time_greater_than_or_equal_to=None, time_less_than_or_equal_to=None):
        if begin_exec_id_greater_than_or_equal_to and not isinstance(begin_exec_id_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'begin_exec_id_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "begin_exec_id_greater_than_or_equal_to", begin_exec_id_greater_than_or_equal_to)
        if end_exec_id_less_than_or_equal_to and not isinstance(end_exec_id_less_than_or_equal_to, str):
            raise TypeError("Expected argument 'end_exec_id_less_than_or_equal_to' to be a str")
        pulumi.set(__self__, "end_exec_id_less_than_or_equal_to", end_exec_id_less_than_or_equal_to)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if index_findings and not isinstance(index_findings, list):
            raise TypeError("Expected argument 'index_findings' to be a list")
        pulumi.set(__self__, "index_findings", index_findings)
        if managed_database_id and not isinstance(managed_database_id, str):
            raise TypeError("Expected argument 'managed_database_id' to be a str")
        pulumi.set(__self__, "managed_database_id", managed_database_id)
        if object_stat_findings and not isinstance(object_stat_findings, list):
            raise TypeError("Expected argument 'object_stat_findings' to be a list")
        pulumi.set(__self__, "object_stat_findings", object_stat_findings)
        if search_period and not isinstance(search_period, str):
            raise TypeError("Expected argument 'search_period' to be a str")
        pulumi.set(__self__, "search_period", search_period)
        if sql_tuning_advisor_task_id and not isinstance(sql_tuning_advisor_task_id, str):
            raise TypeError("Expected argument 'sql_tuning_advisor_task_id' to be a str")
        pulumi.set(__self__, "sql_tuning_advisor_task_id", sql_tuning_advisor_task_id)
        if statistics and not isinstance(statistics, list):
            raise TypeError("Expected argument 'statistics' to be a list")
        pulumi.set(__self__, "statistics", statistics)
        if task_infos and not isinstance(task_infos, list):
            raise TypeError("Expected argument 'task_infos' to be a list")
        pulumi.set(__self__, "task_infos", task_infos)
        if time_greater_than_or_equal_to and not isinstance(time_greater_than_or_equal_to, str):
            raise TypeError("Expected argument 'time_greater_than_or_equal_to' to be a str")
        pulumi.set(__self__, "time_greater_than_or_equal_to", time_greater_than_or_equal_to)
        if time_less_than_or_equal_to and not isinstance(time_less_than_or_equal_to, str):
            raise TypeError("Expected argument 'time_less_than_or_equal_to' to be a str")
        pulumi.set(__self__, "time_less_than_or_equal_to", time_less_than_or_equal_to)

    @property
    @pulumi.getter(name="beginExecIdGreaterThanOrEqualTo")
    def begin_exec_id_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "begin_exec_id_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="endExecIdLessThanOrEqualTo")
    def end_exec_id_less_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "end_exec_id_less_than_or_equal_to")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="indexFindings")
    def index_findings(self) -> Sequence['outputs.GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportIndexFindingResult']:
        """
        The list of object findings related to indexes.
        """
        return pulumi.get(self, "index_findings")

    @property
    @pulumi.getter(name="managedDatabaseId")
    def managed_database_id(self) -> str:
        return pulumi.get(self, "managed_database_id")

    @property
    @pulumi.getter(name="objectStatFindings")
    def object_stat_findings(self) -> Sequence['outputs.GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportObjectStatFindingResult']:
        """
        The list of object findings related to statistics.
        """
        return pulumi.get(self, "object_stat_findings")

    @property
    @pulumi.getter(name="searchPeriod")
    def search_period(self) -> Optional[str]:
        return pulumi.get(self, "search_period")

    @property
    @pulumi.getter(name="sqlTuningAdvisorTaskId")
    def sql_tuning_advisor_task_id(self) -> str:
        return pulumi.get(self, "sql_tuning_advisor_task_id")

    @property
    @pulumi.getter
    def statistics(self) -> Sequence['outputs.GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportStatisticResult']:
        """
        The number of distinct SQL statements with stale or missing optimizer statistics recommendations.
        """
        return pulumi.get(self, "statistics")

    @property
    @pulumi.getter(name="taskInfos")
    def task_infos(self) -> Sequence['outputs.GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportTaskInfoResult']:
        """
        The general information regarding the SQL Tuning Advisor task.
        """
        return pulumi.get(self, "task_infos")

    @property
    @pulumi.getter(name="timeGreaterThanOrEqualTo")
    def time_greater_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "time_greater_than_or_equal_to")

    @property
    @pulumi.getter(name="timeLessThanOrEqualTo")
    def time_less_than_or_equal_to(self) -> Optional[str]:
        return pulumi.get(self, "time_less_than_or_equal_to")


class AwaitableGetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult(GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult(
            begin_exec_id_greater_than_or_equal_to=self.begin_exec_id_greater_than_or_equal_to,
            end_exec_id_less_than_or_equal_to=self.end_exec_id_less_than_or_equal_to,
            id=self.id,
            index_findings=self.index_findings,
            managed_database_id=self.managed_database_id,
            object_stat_findings=self.object_stat_findings,
            search_period=self.search_period,
            sql_tuning_advisor_task_id=self.sql_tuning_advisor_task_id,
            statistics=self.statistics,
            task_infos=self.task_infos,
            time_greater_than_or_equal_to=self.time_greater_than_or_equal_to,
            time_less_than_or_equal_to=self.time_less_than_or_equal_to)


def get_managed_database_sql_tuning_advisor_tasks_summary_report(begin_exec_id_greater_than_or_equal_to: Optional[str] = None,
                                                                 end_exec_id_less_than_or_equal_to: Optional[str] = None,
                                                                 managed_database_id: Optional[str] = None,
                                                                 search_period: Optional[str] = None,
                                                                 sql_tuning_advisor_task_id: Optional[str] = None,
                                                                 time_greater_than_or_equal_to: Optional[str] = None,
                                                                 time_less_than_or_equal_to: Optional[str] = None,
                                                                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult:
    """
    This data source provides details about a specific Managed Database Sql Tuning Advisor Tasks Summary Report resource in Oracle Cloud Infrastructure Database Management service.

    Gets the summary report for the specified SQL Tuning Advisor task.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_sql_tuning_advisor_tasks_summary_report = oci.DatabaseManagement.get_managed_database_sql_tuning_advisor_tasks_summary_report(managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sql_tuning_advisor_task_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        begin_exec_id_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        end_exec_id_less_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        search_period=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_less_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str begin_exec_id_greater_than_or_equal_to: The optional greater than or equal to filter on the execution ID related to a specific SQL Tuning Advisor task. This is applicable only for Auto SQL Tuning tasks.
    :param str end_exec_id_less_than_or_equal_to: The optional less than or equal to query parameter to filter on the execution ID related to a specific SQL Tuning Advisor task. This is applicable only for Auto SQL Tuning tasks.
    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str search_period: How far back the API will search for begin and end exec id. Unused if neither exec ids nor time filter query params are supplied. This is applicable only for Auto SQL Tuning tasks.
    :param str sql_tuning_advisor_task_id: The SQL tuning task identifier. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str time_greater_than_or_equal_to: The optional greater than or equal to query parameter to filter the timestamp. This is applicable only for Auto SQL Tuning tasks.
    :param str time_less_than_or_equal_to: The optional less than or equal to query parameter to filter the timestamp. This is applicable only for Auto SQL Tuning tasks.
    """
    __args__ = dict()
    __args__['beginExecIdGreaterThanOrEqualTo'] = begin_exec_id_greater_than_or_equal_to
    __args__['endExecIdLessThanOrEqualTo'] = end_exec_id_less_than_or_equal_to
    __args__['managedDatabaseId'] = managed_database_id
    __args__['searchPeriod'] = search_period
    __args__['sqlTuningAdvisorTaskId'] = sql_tuning_advisor_task_id
    __args__['timeGreaterThanOrEqualTo'] = time_greater_than_or_equal_to
    __args__['timeLessThanOrEqualTo'] = time_less_than_or_equal_to
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DatabaseManagement/getManagedDatabaseSqlTuningAdvisorTasksSummaryReport:getManagedDatabaseSqlTuningAdvisorTasksSummaryReport', __args__, opts=opts, typ=GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult).value

    return AwaitableGetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult(
        begin_exec_id_greater_than_or_equal_to=__ret__.begin_exec_id_greater_than_or_equal_to,
        end_exec_id_less_than_or_equal_to=__ret__.end_exec_id_less_than_or_equal_to,
        id=__ret__.id,
        index_findings=__ret__.index_findings,
        managed_database_id=__ret__.managed_database_id,
        object_stat_findings=__ret__.object_stat_findings,
        search_period=__ret__.search_period,
        sql_tuning_advisor_task_id=__ret__.sql_tuning_advisor_task_id,
        statistics=__ret__.statistics,
        task_infos=__ret__.task_infos,
        time_greater_than_or_equal_to=__ret__.time_greater_than_or_equal_to,
        time_less_than_or_equal_to=__ret__.time_less_than_or_equal_to)


@_utilities.lift_output_func(get_managed_database_sql_tuning_advisor_tasks_summary_report)
def get_managed_database_sql_tuning_advisor_tasks_summary_report_output(begin_exec_id_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                                                        end_exec_id_less_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                                                        managed_database_id: Optional[pulumi.Input[str]] = None,
                                                                        search_period: Optional[pulumi.Input[Optional[str]]] = None,
                                                                        sql_tuning_advisor_task_id: Optional[pulumi.Input[str]] = None,
                                                                        time_greater_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                                                        time_less_than_or_equal_to: Optional[pulumi.Input[Optional[str]]] = None,
                                                                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetManagedDatabaseSqlTuningAdvisorTasksSummaryReportResult]:
    """
    This data source provides details about a specific Managed Database Sql Tuning Advisor Tasks Summary Report resource in Oracle Cloud Infrastructure Database Management service.

    Gets the summary report for the specified SQL Tuning Advisor task.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_managed_database_sql_tuning_advisor_tasks_summary_report = oci.DatabaseManagement.get_managed_database_sql_tuning_advisor_tasks_summary_report(managed_database_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sql_tuning_advisor_task_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        begin_exec_id_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        end_exec_id_less_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        search_period=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_greater_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_less_than_or_equal_to=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str begin_exec_id_greater_than_or_equal_to: The optional greater than or equal to filter on the execution ID related to a specific SQL Tuning Advisor task. This is applicable only for Auto SQL Tuning tasks.
    :param str end_exec_id_less_than_or_equal_to: The optional less than or equal to query parameter to filter on the execution ID related to a specific SQL Tuning Advisor task. This is applicable only for Auto SQL Tuning tasks.
    :param str managed_database_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Managed Database.
    :param str search_period: How far back the API will search for begin and end exec id. Unused if neither exec ids nor time filter query params are supplied. This is applicable only for Auto SQL Tuning tasks.
    :param str sql_tuning_advisor_task_id: The SQL tuning task identifier. This is not the [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param str time_greater_than_or_equal_to: The optional greater than or equal to query parameter to filter the timestamp. This is applicable only for Auto SQL Tuning tasks.
    :param str time_less_than_or_equal_to: The optional less than or equal to query parameter to filter the timestamp. This is applicable only for Auto SQL Tuning tasks.
    """
    ...
